==> ant-design-vue-2.0.0-rc.9.jar: META-INF/resources/webjars/ant-design-vue/2.0.0-rc.9/lib/table/filterDropdown.d.ts <==
import { Key } from '../_util/type';
declare const _default: import("vue").DefineComponent<{
    locale: import("vue-types").VueTypeLooseShape<{
        filterTitle: string;
        filterConfirm: any;
        filterReset: any;
        emptyText: any;
        selectAll: any;
        selectInvert: any;
        sortTitle: string;
        expand: string;
        collapse: string;
    }>;
    selectedKeys: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    column: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    confirmFilter: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    dropdownPrefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    getPopupContainer: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    handleFilter: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
}, {
    neverShown: boolean;
    sSelectedKeys: unknown[];
    sKeyPathOfSelectedItem: {};
    sVisible: any;
    sValueKeys: {};
}, unknown, {}, {
    getDropdownVisible(): any;
    setNeverShown(column: any): void;
    setSelectedKeys({ selectedKeys }: {
        selectedKeys: any;
    }): void;
    setVisible(visible: boolean): void;
    handleClearFilters(): void;
    handleConfirm(): void;
    onVisibleChange(visible: boolean): void;
    handleMenuItemClick(info: {
        keyPath: Key[];
        key: Key;
    }): void;
    hasSubMenu(): any;
    confirmFilter2(): void;
    renderMenus(items: any): any;
    renderFilterIcon(): JSX.Element;
    renderMenuItem(item: any): JSX.Element;
}, {
    methods: {
        setState(state: {}, callback: any): void;
        __emit(...args: any[]): void;
    };
}, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    prefixCls: string;
    column: {
        [key: string]: any;
    };
    getPopupContainer: (...args: any[]) => any;
    dropdownPrefixCls: string;
    selectedKeys: unknown[];
    confirmFilter: (...args: any[]) => any;
    handleFilter: (...args: any[]) => any;
} & {
    locale?: {
        filterTitle: string;
        filterConfirm: any;
        filterReset: any;
        emptyText: any;
        selectAll: any;
        selectInvert: any;
        sortTitle: string;
        expand: string;
        collapse: string;
    };
}>, {
    prefixCls: string;
    column: {
        [key: string]: any;
    };
    getPopupContainer: (...args: any[]) => any;
    dropdownPrefixCls: string;
    selectedKeys: unknown[];
    confirmFilter: (...args: any[]) => any;
    handleFilter: (...args: any[]) => any;
}>;
export default _default;

==> ant-design-vue-2.1.3.jar: META-INF/resources/webjars/ant-design-vue/2.1.3/lib/table/filterDropdown.d.ts <==
import { Key } from '../_util/type';
declare const _default: import("vue").DefineComponent<{
    locale: import("vue-types").VueTypeLooseShape<{
        filterTitle: (string | ((props: Record<string, unknown>) => string)) & string;
        filterConfirm: any;
        filterReset: any;
        emptyText: any;
        selectAll: any;
        selectInvert: any;
        sortTitle: (string | ((props: Record<string, unknown>) => string)) & string;
        expand: (string | ((props: Record<string, unknown>) => string)) & string;
        collapse: (string | ((props: Record<string, unknown>) => string)) & string;
    }>;
    selectedKeys: import("vue-types").VueTypeValidableDef<unknown[]> & {
        default: () => unknown[];
    };
    column: import("vue-types").VueTypeValidableDef<{
        [key: string]: any;
    }> & {
        default: () => {
            [key: string]: any;
        };
    };
    confirmFilter: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    prefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    dropdownPrefixCls: import("vue-types").VueTypeValidableDef<string> & {
        default: string;
    };
    getPopupContainer: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
    handleFilter: import("vue-types").VueTypeValidableDef<(...args: any[]) => any> & {
        default: (...args: any[]) => any;
    };
}, {
    neverShown: boolean;
    sSelectedKeys: unknown[];
    sKeyPathOfSelectedItem: {};
    sVisible: any;
    sValueKeys: {};
}, unknown, {}, {
    getDropdownVisible(): any;
    setNeverShown(column: any): void;
    setSelectedKeys({ selectedKeys }: {
        selectedKeys: any;
    }): void;
    setVisible(visible: boolean): void;
    handleClearFilters(): void;
    handleConfirm(): void;
    onVisibleChange(visible: boolean): void;
    handleMenuItemClick(info: {
        keyPath: Key[];
        key: Key;
    }): void;
    hasSubMenu(): any;
    confirmFilter2(): void;
    renderMenus(items: any): any;
    renderFilterIcon(): import("vue").VNode<any, any, {
        [key: string]: any;
    }>;
    renderMenuItem(item: any): JSX.Element;
}, {
    methods: {
        setState(state: {}, callback: any): void;
        __emit(...args: any[]): void;
    };
}, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    prefixCls: string;
    column: {
        [key: string]: any;
    };
    getPopupContainer: (...args: any[]) => any;
    dropdownPrefixCls: string;
    selectedKeys: unknown[];
    confirmFilter: (...args: any[]) => any;
    handleFilter: (...args: any[]) => any;
} & {
    locale?: {
        filterTitle: (string | ((props: Record<string, unknown>) => string)) & string;
        filterConfirm: any;
        filterReset: any;
        emptyText: any;
        selectAll: any;
        selectInvert: any;
        sortTitle: (string | ((props: Record<string, unknown>) => string)) & string;
        expand: (string | ((props: Record<string, unknown>) => string)) & string;
        collapse: (string | ((props: Record<string, unknown>) => string)) & string;
    };
}>, {
    prefixCls: string;
    column: {
        [key: string]: any;
    };
    getPopupContainer: (...args: any[]) => any;
    dropdownPrefixCls: string;
    selectedKeys: unknown[];
    confirmFilter: (...args: any[]) => any;
    handleFilter: (...args: any[]) => any;
}>;
export default _default;
